##  Limitations for Fields
The table below lists the fields for which specific operations are not supported.
Unsupported Operations for Fields Operation | Not Supported for Fields
---|---
Update |
  * id
  * type
  * rev
  * level
  * completion
  * updatedAt
  * createdAt


Delete |
  * name




